#
# spec file for package php-memcached
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    memcached

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        3.3.0
Release:        1.5
Summary:        PHP MemcacheD client Extension
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/memcached
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
BuildRequires:  %{php_name}-devel
%if 0%{?suse_version} > 1500
BuildRequires:  fastlzlib-devel
%endif
BuildRequires:  libmemcached-devel >= 1.0.10
BuildRequires:  memcached
BuildRequires:  zlib-devel
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
%if "%{php_name}" == "php7"
BuildRequires:  %{php_name}-json
Requires:       %{php_name}-json
%endif

%description
This extension uses libmemcached library to provide API for
communicating with memcached servers.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure \
	--enable-memcached \
%if 0%{?suse_version} > 1500
	--with-system-fastlz \
%endif
	--enable-memcached-json
%make_build

%check
%if "%{php_name}" == "php7"
export TEST_PHP_ARGS="$TEST_PHP_ARGS -d extension=%{php_extdir}/json.so"
%endif

if [ -x %{_sbindir}/memcached ]; then
  export MEMCACHED_BIN=%{_sbindir}/memcached
elif [ -x %{_bindir}/memcached ]; then
  export MEMCACHED_BIN=%{_bindir}/memcached
else
  echo "Failed to start memcached - tests can't pass"
  exit 1
fi

$MEMCACHED_BIN -P /tmp/memcached.pid -p 11211 -U 11211 -d
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test
kill -TERM $(cat /tmp/memcached.pid)

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini <<EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so

EOF
cat %{pkg_name}.ini >> %{buildroot}%{php_cfgdir}/%{pkg_name}.ini

%files
%defattr(-,root,root)
%license LICENSE
%doc ChangeLog CREDITS memcached-api.php README.markdown
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Thu Oct 17 2024 Arjen de Korte <suse+build@de-korte.org>
- Update to 3.3.0
  * Add #515 option to locally enforce payload size limit
  * Add #539 zstd support
  * Add #540 compression_level option
  * Mark password as a sensitive param for PHP 8.2
  * Upgrade Windows libmemcached to v1.1.4
  * Fix Windows PHP 8 compatibility
  * Fix #518 Windows msgpack support
  * Fix #522 signed integer overflow
  * Fix #523 incorrect PHP reflection type for Memcached::cas $cas_token
  * Fix #546 don't check key automatically, unless client-side verify_key is enabled
  * Fix #555 incompatible pointer types (32-bit)
- Remove patch (upstreamed)
  - fc388e65e7ceab9e6d52bc77b6306f71db981873.patch
* Wed Apr 12 2023 Arjen de Korte <suse+build@de-korte.org>
- Fix ${var} deprecation
  + fc388e65e7ceab9e6d52bc77b6306f71db981873.patch
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Wed Nov 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Adjust to memcached now being installed in /usr/bin instead of
  /usr/sbin.
* Thu Mar 24 2022 Arjen de Korte <suse+build@de-korte.org>
- Update to 3.2.0
  * PHP 8.0 and 8.1 support
  * store_retry_count is no more set explicitly (#452)
  * fix MemcachedServer (libmemcached-awesome is recommended)
  * code cleanup
  * remove patches no longer needed
  - fixup-unit-tests-broken-in-php8.patch
  - fixup-unit-tests.patch
  - fix-zend_dtoa-API-change.patch
* Tue Jan 25 2022 Arjen de Korte <suse+build@de-korte.org>
- Fix zend_dtoa API change in 8.1.0beta1
  + fix-zend_dtoa-API-change.patch
* Fri Jan 29 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Change to 'more complete' multibuild: build all flavors (php7 and
  php8) as flavors. The base package (flavor="") is not being
  built.
- Ensure the Name: tag matches the spec file name in case of
  flavor="".
* Fri Jan 29 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
* Sun Jan 24 2021 Arjen de Korte <suse+build@de-korte.org>
- Use system FastLZ library instead of built-in version
* Sun Jan 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use php_cfgdir and php_extdir macros to determine location of files
* Tue Dec  3 2019 Arjen de Korte <suse+build@de-korte.org>
- Update to 3.1.5
  * Fix build with PHP 7.4 release due to ulong typedef removal
* Mon Dec  2 2019 Arjen de Korte <suse+build@de-korte.org>
- Add 'BuildRequires: pkgconfig(zlib)' so that the location of the
  header files can be autodetected
* Mon Oct  7 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 3.1.4
  * Test on PHP 7.4 as well as 8.0 (#440)
  * Fix segfault for unknown memcached flags (#431)
  * Update documented defaults for sess_lock_retries (#432)
  * Remove stray instances of the TSRMLS_CC macro for PHP 8 compatibility (#444)
* Thu Dec 27 2018 suse+build@de-korte.org
- Update to 3.1.3
  * Fix --disable-memcached-session by ifdef-ing session INI handler
    callbacks (#396, #420)
* Sat Dec 22 2018 suse+build@de-korte.org
- Update to 3.1.2
  * Fix --enable-memcached-protocol was set to yes by default, reverted
    to no (#418)
- Update to 3.1.1
  * Fix --disable-memcached-sasl and --disable-memcached-session replaced
    by --enable variants (#416)
- Update to 3.1.0
  * Support for PHP 7.3 (#385, #390)
  * Add INI setting to choose session consistent hash (ketama or
    ketama_weighted) (#344, #392)
  * Add support for libmemcached encryption (#345, #381)
  * Add error reporting to session code (#165)
  * Expose build configuration via PECL (#383)
  * Fix hanging getStats() when binary protocol and non-blocking
    are both enabled (#348)
  * Fix session persistence by checking memcached behavior values
    before setting (#379)
  * Fix memcached.sess_persistent not working with
    memcached.sess_binary_protocol = On (#375)
  * Configure warns if libmemcached needs sasl.h (#341, #380)
  * Resolve various INI deviations in 3.0.3 (#351)
  * Turn off sess_binary_protocol by default with older libmemcached
    (#330)
  * Impove Windows builds (#411)
  * Support Homebrew ZLIB path (#410)
  * Remove forgotten unused comment about -lpthread (#406)
  * Git ignore configure.ac (#405)
  * Replace obsolete macros AC_TRY_FOO with AC_FOO_IFELSE (#403)
  * Remove unused defines (#354)
  * Change session_lock and sess_prefix default ini values (#340, #350)
  * Use new fast_zpp parameter parsing API (#302, #311)
* Thu May  3 2018 mlin@suse.com
- Update to 3.0.4
  * PHP 7.0 - 7.1 - 7.2 release of memcached extension. Note that support for
    libmemcached 0.x series has been discontinued and the oldest actively tested
    version is 1.0.2. It is highly recommended to use version 1.0.18 of
    libmemcached.
  * Fix corrupted interned strings (#338)
  * Fix unit tests for compatibility with PHP 7.2 (#358, #359)
  * Fix \x0a in key name locks up connection and triggers a fatal timeout error (#339)
  * Fix missing optional parameter getStats($type) (#337)
  * Fix typo in skip message (#331)
  * Fix build warnings (329)
  * Document GET_EXTENDED flag, add/rename other missing/misnamed constants (#335)
* Wed Mar 21 2018 crrodriguez@opensuse.org
- Build extension with fvisibility=hidden to limit symbol
  exposure and/or symbols clashes.
* Thu Aug 10 2017 sflees@suse.de
- Add refs fate#322501 bsc#1045750 to keep SLE Checker bots happy
* Mon Mar 20 2017 jweberhofer@weberhofer.at
- updated to 3.0.3
  * Fix crash when checking session data with older versions
    of libmemcached (#328)
  * Fix crash due to zend_mm_corrupted when fetching session
    data (#327)
- updated to 3.0.2
  * Update warning for touch command in binary protocol mode with
    libmemcached below 1.0.18 (#322)
  * Add tests for 64-bit
    increment/decrement/incrementByKey/decrementByKey (#321)
  * Fix tests for 32-bit
    increment/decrement/incrementByKey/decrementByKey (#319)
- updated to 3.0.1
  * Add API entries for flushBuffers() and getAllKeys() (#316)
  * Ignore specific errors from memcached_dump for getAllKeys()
    with newer memcached servers (#315)
  * Fix compiling with memcached binary protocol enabled (#312)
  * Restore php_libmemcached_compat with workaround for missing
    memcached_exists (#314)
  * Travis CI purge old versions of memcached and libmemcached (#309)
- updated to 3.0.0
  API
  * The method signature of get, getByKey, getMulti, and getMultiByKey changed.
  * get* and getMulti* commands no longer take cas or user flags parameters.
  * get* and getMulti* commands now take the Memcached::GET_EXTENDED flag to
    retrieve user flags and cas tokens.
  * Fixes getStats command to return all stats from all servers
  * Fixes allKeys command behaviour
  * Fixes error where cache callback for get command was not setting
    expiration time properly
  * Added server type to server list
  * Remove use_sasl ini-variable and initialise sasl as needed
  * CAS tokens are returned as integers and they overflow to strings as needed
  Session handler
  * The session memcached protocol config name was changed, and the default
    protocol was changed from text to binary protocol. If your memcached
    setup does not support the binary protocol(e.g. if using twemproxy),
    then set memcached.sess_binary_protocol = Off. (Previously called
    memcached.sess_binary)
  * Session lock algorithm updated (new ini-values
    memcached.sess_lock_wait_min, memcached.sess_lock_wait_max and
    memcached.sess_lock_retries)
  * Session extension uses PHP allocators (still some work to do on the rest
    of the extension)
  * Ini-values take effect during session_start or session_regenerate_id
  * Fixes crash with session_regenerate_id (work-around for PHP bug)
  Tests
  * Fix several problematic tests
* Fri Feb 19 2016 pgajdos@suse.com
- renamed to php7-memcached
- updated to git6ace07d
* Fri Feb 19 2016 pgajdos@suse.com
- do not require php5-igbinary for 13.1
* Sun Aug 24 2014 munix9@googlemail.com
- update to version 2.2.0
  * Added the OPT_SERVER_TIMEOUT_LIMIT behaviour
- update to version 2.2.0RC1
  * Fixes incorrect size when compressing serialized objects
  * Fixes endianess of compressed values
- update to version 2.2.0b1
  * Reinstate support for libememcached 0.x series
  * Added SASL support to session handler
  * Added Memcached::flushBuffers as per GH #78
  * Fixes GH #54: Fixed UDP server adding with newer libmemcached
  * Fixed PHP bug #65334: (Segfault if uncompress value failed)
  * Fixes GH #14: get with cas token fails to fetch all results
  * Fixes GH #68: memcached 2.1.0 requires libmemcached 1.0.10
  * Fixes GH #69: compiling on CentOS 6.4 with libmemcached 1.0.17
  * Merged PR #91: More granular session locking support
  * Added session handler settings:
  - memcached.sess_number_of_replicas
  - memcached.sess_randomize_replica_read
  - memcached.sess_remove_failed
  - memcached.sess_connect_timeout
  * Added support for memcached protocol handlers
  * Added Memcached::setBucket for virtual bucket support
  * Added support for msgpack serialization
  * Memcached::setSaslAuthData returns correct status on success
  * Added support for user-defined flags in set and get operations
* Fri Jul 12 2013 munix9@googlemail.com
- replaced source package with the original from github,
  added pull_request_42.patch and pull_request_56.patch
* Tue Feb 12 2013 munix9@googlemail.com
- initial package for version 2.1.0
  * Drop support for libmemcached 0.x series, now 1.0.x is required
  * Add support for virtual bucket distribution
  * Fix compilation against PHP 5.2
